import { useRuntimeConfig, useState, useFetch, navigateTo, createError, useRoute, h, resolveComponent } from "#imports";
export const useDrupalCe = () => {
  const fetchPage = async (path, useFetchOptions = {}) => {
    const config = useRuntimeConfig();
    const baseURL = config.public.drupalCe.baseURL;
    const pageState = useState(`page-${path}`, () => {
    });
    useFetchOptions.query = useFetchOptions.query ?? {};
    useFetchOptions.key = `page-${path}`;
    useFetchOptions.baseURL = baseURL;
    const { data: page, error } = await useFetch(path, useFetchOptions);
    if (page?.value?.redirect) {
      await navigateTo(page.value.redirect.url, {
        external: page.value.redirect.external,
        redirectCode: page.value.redirect.statusCode
      });
      return;
    }
    if (error.value && !error.value?.data?.content) {
      throw createError({ statusCode: error.value.status, statusMessage: error.value.message, fatal: true });
    }
    if (error.value) {
      page.value = error.value?.data;
    }
    page.value?.messages && pushMessagesToState(page.value.messages);
    pageState.value = page;
    return page;
  };
  const fetchMenu = async (name) => {
    const config = useRuntimeConfig();
    const baseURL = config.public.drupalCe.baseURL;
    const menuEndpoint = config.public.drupalCe.menuEndpoint;
    const menuPath = menuEndpoint.replace("$$$NAME$$$", name);
    const { data: menu, error } = await useFetch(menuPath, {
      key: `menu-${name}`,
      baseURL
    });
    if (error.value) {
      errorMenuHandler(error);
      return;
    }
    return menu;
  };
  const getMessages = () => useState("drupal-ce-messages", () => []);
  const getPage = () => useState(`page-${useRoute().path}`);
  const renderCustomElements = (customElement) => {
    return h(resolveComponent(customElement.element), customElement);
  };
  return {
    fetchPage,
    fetchMenu,
    getMessages,
    getPage,
    renderCustomElements
  };
};
const pushMessagesToState = (messages) => {
  messages = Object.assign({ success: [], error: [] }, messages);
  const messagesArray = [
    ...messages.error.map((message) => ({ type: "error", message })),
    ...messages.success.map((message) => ({ type: "success", message }))
  ];
  if (!messagesArray.length) {
    return;
  }
  process.client && useDrupalCe().getMessages().value.push(...messagesArray);
};
const errorMenuHandler = (error) => {
  process.client && useDrupalCe().getMessages().value.push({
    type: "error",
    message: `Menu error: ${error.value.message}.`
  });
};
